==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/ToolActionGroupHeaderInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionInfoDescriptionMetadata } from "./ToolActionInfoDescriptionMetadata";
import { ToolActionGroupHeaderInfoDescription } from "./ToolActionGroupHeaderInfoDescription";
/**
 * @hidden
 */
export let ToolActionGroupHeaderInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionGroupHeaderInfoDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionGroupHeaderInfoDescriptionMetadata.a == null) {
                ToolActionGroupHeaderInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionGroupHeaderInfoDescriptionMetadata.c(ToolActionGroupHeaderInfoDescriptionMetadata.a);
            }
            if (a.k(ToolActionGroupHeaderInfoDescriptionMetadata.a)) {
                return;
            }
            a.ab(ToolActionGroupHeaderInfoDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionInfoDescriptionMetadata.c(a);
        }
        static d(a) {
            ToolActionGroupHeaderInfoDescriptionMetadata.b(a);
            a.ad("ToolActionGroupHeaderInfo", () => new ToolActionGroupHeaderInfoDescription());
            a.ac("ToolActionGroupHeaderInfo", ToolActionGroupHeaderInfoDescriptionMetadata.a);
        }
    }
    ToolActionGroupHeaderInfoDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolActionGroupHeaderInfoDescriptionMetadata, 'ToolActionGroupHeaderInfoDescriptionMetadata');
    ToolActionGroupHeaderInfoDescriptionMetadata.a = null;
    return ToolActionGroupHeaderInfoDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/ToolActionGroupHeaderInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionInfoDescriptionMetadata } from "./ToolActionInfoDescriptionMetadata";
import { ToolActionGroupHeaderInfoDescription } from "./ToolActionGroupHeaderInfoDescription";
/**
 * @hidden
 */
export let ToolActionGroupHeaderInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionGroupHeaderInfoDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionGroupHeaderInfoDescriptionMetadata.a == null) {
                ToolActionGroupHeaderInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionGroupHeaderInfoDescriptionMetadata.c(ToolActionGroupHeaderInfoDescriptionMetadata.a);
            }
            if (a.k(ToolActionGroupHeaderInfoDescriptionMetadata.a)) {
                return;
            }
            a.ac(ToolActionGroupHeaderInfoDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionInfoDescriptionMetadata.c(a);
        }
        static d(a) {
            ToolActionGroupHeaderInfoDescriptionMetadata.b(a);
            a.ae("ToolActionGroupHeaderInfo", () => new ToolActionGroupHeaderInfoDescription());
            a.ad("ToolActionGroupHeaderInfo", ToolActionGroupHeaderInfoDescriptionMetadata.a);
        }
    }
    ToolActionGroupHeaderInfoDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolActionGroupHeaderInfoDescriptionMetadata, 'ToolActionGroupHeaderInfoDescriptionMetadata');
    ToolActionGroupHeaderInfoDescriptionMetadata.a = null;
    return ToolActionGroupHeaderInfoDescriptionMetadata;
})();
